#! /bin/sh
# $Id: genquotes.sh,v 1.2 2003/09/02 19:28:24 trm Exp trm $

## 
## Usage: genquotes.sh [options] [fortune-options]
## 
##   Uses "fortune" to generate quote files suitable for sgrotum.
## 
## Options:
##   -h,--help       Show this usage message
##   -M,--max NUM    Maximum number of quotes to generate (default is 50)
## 
## Examples:
##   genquotes.sh > misc-quotes
##   genquotes.sh riddles > riddle-quotes
##   genquotes.sh 80% linux 10% science 10% startrek > geeky-quotes
##   genquotes.sh --max 200 -n 72 > short-quotes
## 
# Han Boetes <han@boetes.org>
# Tim Musson <trmusson@ihug.co.nz>


FORTUNE=fortune
TMPFILE=/tmp/genquotes.$$
NQUOTES=50


PROGNAME=`basename $0`


if [ "$1" = "-h" -o "$1" = "--help" ]; then
  sed -n '/^##/s/^## //p' $0
  exit 0
elif [ "$1" = "-M" -o "$1" = "--max" ]; then
  shift
  NQUOTES=$1
  shift
fi


while [ "$NQUOTES" -gt 0 ]; do
  $FORTUNE -s $@ | tr '\n' ' ' >> $TMPFILE
  echo >> $TMPFILE
  NQUOTES=`expr $NQUOTES - 1`
done

# remove junk characters and duplicates
cat $TMPFILE | tr -d '[_	]' |
  sed -e 's/[[:space:]]\+/ /g' | sort | uniq -u

rm $TMPFILE

